]> Shamusworld >> Repos - rmac/blobdiff - token.h
Bump version #.
[rmac] / token.h
diff --git a/token.h b/token.h
index becd0747f9a6ba93e79566ef258025afad109feb..c44989c09f7ca99651f9287432c23828b8e909e7 100644 (file)
--- a/token.h
+++ b/token.h
@@ -3,14 +3,13 @@
 // TOKEN.H - Token Handling
 // Copyright (C) 199x Landon Dyer, 2011 Reboot and Friends
 // RMAC derived from MADMAC v1.07 Written by Landon Dyer, 1986
-// Source Utilised with the Kind Permission of Landon Dyer
+// Source utilised with the kind permission of Landon Dyer
 //
 
 #ifndef __TOKEN_H__
 #define __TOKEN_H__
 
 #include "rmac.h"
-//#include "risca.h"
 
 // Include Files and Macros
 #define SRC_IFILE       0                                      // Input source is IFILE
@@ -63,6 +62,7 @@
 #define CR_MACDEF       'w'                                    // ^^macdef - is macro defined?
 #define CR_TIME         'x'                                    // ^^time - DOS format time
 #define CR_DATE         'y'                                    // ^^date - DOS format date
+#define CR_ABSCOUNT     'z'                                    // ^^abscount - count the number of bytes defined in curent .abs section
 
 // Character Attributes
 #define ILLEG           0                                      // Illegal character (unused)
@@ -112,8 +112,8 @@ IFILE {
 
 #define TOKENSTREAM struct _tokenstream
 TOKENSTREAM {
-       TOKEN token[10];                // 10 ought to be enough for anybody
-       char * string[10];              // same for attached strings
+       TOKEN token[32];                // 32 ought to be enough for anybody (including XiA!)
+       char * string[32];              // same for attached strings
 };
 
 // Information about a macro invocation
@@ -155,9 +155,9 @@ extern char * string[];
 
 // Prototypes
 int include(int, char *);
-void init_token(void);
+void InitTokenizer(void);
 void SetFilenameForErrorReporting(void);
-int tokln(void);
+int TokenizeLine(void);
 int fpop(void);
 int d_goto(WORD);
 //int d_goto(void);